@@ -136,7 +136,7 @@ pub struct EnumSet<T : EnumSetType> {
 }
 impl <T : EnumSetType> EnumSet<T> {
     fn mask(bit: u8) -> T::Repr {
-        T::Repr::one() << bit as usize
+        Shl::<usize>::shl(T::Repr::one(), bit as usize)
     }
     fn has_bit(&self, bit: u8) -> bool {
         let mask = Self::mask(bit);
@@ -782,6 +782,16 @@ mod test {
                     assert!(set.is_empty());
                 }
 
+                #[test]
+                fn empty_is_empty() {
+                    assert_eq!(EnumSet::<$e>::empty().len(), 0)
+                }
+
+                #[test]
+                fn all_len() {
+                    assert_eq!(EnumSet::<$e>::all().len(), EnumSet::<$e>::bit_width() as usize)
+                }
+
                 #[test]
                 fn basic_iter_test() {
                     let mut set = EnumSet::new();
